aboutsummaryrefslogtreecommitdiff
path: root/src/script.h
diff options
context:
space:
mode:
authorPieter Wuille <pieter.wuille@gmail.com>2014-02-07 02:19:48 +0100
committerPieter Wuille <sipa@ulyssis.org>2014-03-10 20:38:32 +0100
commit6fd7ef2bbf1f941c8dee302ffdeb44e603148723 (patch)
tree76cebc090b484368a68781cb393b1e1be7ad1717 /src/script.h
parenta63f8b7b36e39722024a0ba061ca214f00a8f1bd (diff)
downloadbitcoin-6fd7ef2bbf1f941c8dee302ffdeb44e603148723.tar.xz
Also switch the (unused) verification code to low-s instead of even-s.
a81cd968 introduced a malleability breaker for signatures (using an even value for S). In e0e14e43 this was changed to the lower of two potential values, rather than the even one. Only the signing code was changed though, the (for now unused) verification code wasn't adapted.
Diffstat (limited to 'src/script.h')
-rw-r--r--src/script.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/script.h b/src/script.h
index 657ac0b388..b96bbc45c3 100644
--- a/src/script.h
+++ b/src/script.h
@@ -40,7 +40,7 @@ enum
SCRIPT_VERIFY_NONE = 0,
SCRIPT_VERIFY_P2SH = (1U << 0), // evaluate P2SH (BIP16) subscripts
SCRIPT_VERIFY_STRICTENC = (1U << 1), // enforce strict conformance to DER and SEC2 for signatures and pubkeys
- SCRIPT_VERIFY_EVEN_S = (1U << 2), // enforce even S values in signatures (depends on STRICTENC)
+ SCRIPT_VERIFY_LOW_S = (1U << 2), // enforce low S values (<n/2) in signatures (depends on STRICTENC)
SCRIPT_VERIFY_NOCACHE = (1U << 3), // do not store results in signature cache (but do query it)
};